from django.apps import AppConfig


class WagtailTextractAppConfig(AppConfig):
    """Wagtail-Textract AppConfig."""
    name = 'wagtail_textract'
    label = 'wagtail_textract'
    verbose_name = "Wagtail-Textract Search integration"
