# Generated by Django 2.0.4 on 2018-05-08 09:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_textract', '0003_auto_20180503_1117'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='document',
            options={},
        ),
    ]
