# Generated by Django 2.0.4 on 2018-05-08 09:45

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    replaces = [('wagtail_textract', '0001_initial'), ('wagtail_textract', '0002_auto_20180502_1303'), ('wagtail_textract', '0003_auto_20180503_1117'), ('wagtail_textract', '0004_auto_20180508_0942')]

    initial = True

    dependencies = [
        ('wagtaildocs', '0007_merge'),
    ]

    operations = [
        migrations.CreateModel(
            name='Document',
            fields=[
                ('document_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtaildocs.Document')),
                ('transcription', models.TextField(blank=True, default='')),
            ],
            options={
                'verbose_name': 'document',
                'abstract': False,
            },
            bases=('wagtaildocs.document',),
        ),
    ]
